@@ -104,17 +104,17 @@ class DatabaseController:
     def create_datapackage(self, **args):
         return self._create(self.DataPackageController, **args)
 
-    def remove_datapackage(self, query="1 == 1"):
+    def remove_datapackage(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which datapackages are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.DataPackageController, query=query)
 
-    def query_datapackage(self, query="1 == 1", column=['*']):
+    def query_datapackage(self, query="1=1", column=['*']):
         return self._query(controller=self.DataPackageController, query=query, columns=column)
 
-    def update_datapackage(self, column_value=None, query="1 == 1"):
+    def update_datapackage(self, column_value=None, query="1=1"):
         return self._update(controller=self.DataPackageController, query=query, column_value=column_value)
 
     def _create(self, controller, **args):
@@ -173,7 +173,7 @@ class DatabaseController:
                 self.session.rollback()
                 self.session.close()
                 self.session = self.create_Session()
-                obj = self.query_CoT(f'uid == "{args["CoT"].uid}"')[0]
+                obj = self.query_CoT(f'uid = "{args["CoT"].uid}"')[0]
                 self.session.delete(obj)
                 self.session.commit()
                 return self._create(controller=self.UserTableController, **args)
@@ -181,48 +181,51 @@ class DatabaseController:
                 self.session.rollback()
                 self.session.close()
                 self.session = self.create_Session()
-    def remove_user(self, query="1 == 1"):
+                raise Exception(e)
+    def remove_user(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which datapackages are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.UserTableController, query=query)
 
-    def query_user(self, query="1 == 1", column=['*']):
+    def query_user(self, query="1=1", column=['*']):
         return self._query(controller=self.UserTableController, query=query, columns=column)
 
-    def update_user(self, column_value=dict(), query="1 == 1"):
+    def update_user(self, column_value=dict(), query="1=1"):
         return self._update(controller=self.UserTableController, query=query, column_value=column_value)
 
     def create_systemUser(self, **args):
         try:
             return self._create(controller=self.SystemUserTableController, **args)
         except Exception as e:
+            print(e)
             self.session.rollback()
             self.session.commit()
-    def remove_systemUser(self, query="1 == 1"):
+            raise Exception(e)
+    def remove_systemUser(self, query="1=1"):
         return self._remove(controller=self.SystemUserTableController, query=query)
 
-    def query_systemUser(self, query="1 == 1", column=['*']):
+    def query_systemUser(self, query="1=1", column=['*']):
         return self._query(controller=self.SystemUserTableController, query=query, columns=column)
 
-    def update_systemUser(self, column_value=dict(), query="1 == 1"):
+    def update_systemUser(self, column_value=dict(), query="1=1"):
         return self._update(controller=self.SystemUserTableController, query=query, column_value=column_value)
 
     def create_videostream(self, **args):
         return self._create(controller=self.VideoStreamTableController, **args)
 
-    def remove_videostream(self, query="1 == 1"):
+    def remove_videostream(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which datapackages are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.VideoStreamTableController, query=query)
 
-    def query_videostream(self, query="1 == 1", column=['*']):
+    def query_videostream(self, query="1=1", column=['*']):
         return self._query(controller=self.VideoStreamTableController, query=query, columns=column)
 
-    def update_videostream(self, column_value=dict(), query="1 == 1"):
+    def update_videostream(self, column_value=dict(), query="1=1"):
         return self._update(controller=self.VideoStreamTableController, query=query, column_value=column_value)
 
     def create_CoT(self, object):
@@ -235,7 +238,7 @@ class DatabaseController:
             try:
                 session.rollback()
                 session.close()
-                obj = self.query_CoT(f'uid == "{object.uid}"')[0]
+                obj = self.query_CoT(f'uid = "{object.uid}"')[0]
                 newobj = self.EventTableController.convert_model_to_row(object)
                 self.session.delete(obj)
                 self.session.commit()
@@ -248,33 +251,33 @@ class DatabaseController:
                 raise e
         except Exception as e:
             self.session.rollback()
-    def remove_CoT(self, query="1 == 1"):
+    def remove_CoT(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which datapackages are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.EventTableController, query=query)
 
-    def query_CoT(self, query="1 == 1", column=['*']):
+    def query_CoT(self, query="1=1", column=['*']):
         return self._query(controller=self.EventTableController, query=query, columns=column)
 
-    def update_CoT(self, column_value=dict(), query="1 == 1"):
+    def update_CoT(self, column_value=dict(), query="1=1"):
         return self._update(controller=self.EventTableController, query=query, column_value=column_value)
 
     def create_APIUser(self, **args):
         return self._create(self.APIUserController, **args)
 
-    def remove_APIUser(self, query="1 == 1"):
+    def remove_APIUser(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which datapackages are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.APIUserController, query=query)
 
-    def query_APIUser(self, query="1 == 1", column=['*']):
+    def query_APIUser(self, query="1=1", column=['*']):
         return self._query(controller=self.APIUserController, query=query, columns=column)
 
-    def update_APIUser(self, column_value=None, query="1 == 1"):
+    def update_APIUser(self, column_value=None, query="1=1"):
         return self._update(controller=self.APIUserController, query=query, column_value=column_value)
 
     def create_ActiveEmergency(self, object):
@@ -282,15 +285,18 @@ class DatabaseController:
             session = self.create_Session()
             self.ActiveEmergencysController.create(session, object)
         except Exception as e:
+            print(e)
             session.rollback()
             session.close()
-    def remove_ActiveEmergency(self, query="1 == 1"):
+            raise Exception(e)
+
+    def remove_ActiveEmergency(self, query="1=1"):
         return self._remove(controller=self.ActiveEmergencysController, query=query)
 
-    def query_ActiveEmergency(self, query="1 == 1", column=['*']):
+    def query_ActiveEmergency(self, query="1=1", column=['*']):
         return self._query(controller=self.ActiveEmergencysController, query=query, columns=column)
 
-    def update_ActiveEmergency(self, column_value=None, query="1 == 1"):
+    def update_ActiveEmergency(self, column_value=None, query="1=1"):
         return self._update(controller=self.ActiveEmergencysController, query=query, column_value=column_value)
 
 
@@ -304,75 +310,75 @@ class DatabaseController:
             session.rollback()
             session.close()
 
-    def remove_ExCheck(self, query="1 == 1"):
+    def remove_ExCheck(self, query="1=1"):
         return self._remove(controller=self.ExCheckController, query=query)
 
-    def query_ExCheck(self, query = "1==1", column=["*"], verbose = False):
+    def query_ExCheck(self, query = "1=1", column=["*"], verbose = False):
         if verbose == False:
             return self._query(controller=self.ExCheckController, query=query, columns=column)
         else:
             return self.ExCheckController.queryChildren(query, column, self.session)
-    def update_ExCheck(self, query="1==1", column_value=None):
+    def update_ExCheck(self, query="1=1", column_value=None):
         return self._update(controller=self.ExCheckController, query=query, column_value=column_value)
 
     def create_Excheckchecklist(self, **args):
         return self._create(self.ExCheckChecklistController, **args)
 
-    def remove_ExCheckChecklist(self, query="1 == 1"):
+    def remove_ExCheckChecklist(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which exCheckChecklists are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.ExCheckChecklistController, query=query)
 
-    def query_ExCheckChecklist(self, query="1 == 1", column=['*']):
+    def query_ExCheckChecklist(self, query="1=1", column=['*']):
         return self._query(controller=self.ExCheckChecklistController, query=query, columns=column)
 
-    def update_ExCheckChecklist(self, column_value=None, query="1 == 1"):
+    def update_ExCheckChecklist(self, column_value=None, query="1=1"):
         return self._update(controller=self.ExCheckChecklistController, query=query, column_value=column_value)
 
     def create_ActiveFederation(self, **args):
         return self._create(self.ActiveFederationController, **args)
 
-    def remove_ActiveFederation(self, query="1 == 1"):
+    def remove_ActiveFederation(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which exCheckChecklists are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.ActiveFederationController, query=query)
 
-    def query_ActiveFederation(self, query="1 == 1", column=['*']):
+    def query_ActiveFederation(self, query="1=1", column=['*']):
         return self._query(controller=self.ActiveFederationController, query=query, columns=column)
 
-    def update_ActiveFederation(self, column_value=None, query="1 == 1"):
+    def update_ActiveFederation(self, column_value=None, query="1=1"):
         return self._update(controller=self.ActiveFederationController, query=query, column_value=column_value)
 
     def create_Federation(self, **args):
         return self._create(self.FederationController, **args)
 
-    def remove_Federation(self, query="1 == 1"):
+    def remove_Federation(self, query="1=1"):
         '''
         :param query: this parameter will be used to select which exCheckChecklists are deleted
         :return: 1 on success
         '''
         return self._remove(controller=self.FederationController, query=query)
 
-    def query_Federation(self, query="1 == 1", column=['*']):
+    def query_Federation(self, query="1=1", column=['*']):
         return self._query(controller=self.FederationController, query=query, columns=column)
 
-    def update_Federation(self, column_value=None, query="1 == 1"):
+    def update_Federation(self, column_value=None, query="1=1"):
         return self._update(controller=self.FederationController, query=query, column_value=column_value)
 
     def create_APICall(self, **args):
         return self._create(self.APICallController, **args)
 
-    def remove_APICall(self, query="1==1"):
+    def remove_APICall(self, query="1=1"):
         return self._remove(controller = self.APICallController, query = query)
 
-    def query_APICall(self, query="1==1", column=["*"]):
+    def query_APICall(self, query="1=1", column=["*"]):
         return self._query(controller=self.APICallController, query=query, columns=column)
 
-    def update_APICall(self, column_value = None, query="1==1"):
+    def update_APICall(self, column_value = None, query="1=1"):
         return self._update(controller=self.APICallController, query=query, column_value=column_value)
 
     def shutdown_Connection(self):
@@ -403,12 +409,6 @@ if __name__ == "__main__":
     y = contr.session.query(Event).filter(or_(and_(Point.lon<0, Point.lat<0, (((((Point.lon*-1)-lon_abs)*111302.62) + (((Point.lat*-1)-lat_abs)*110574.61)) <= radius)), and_(Point.lon<0, Point.lat>=0, (((((Point.lon*-1)-lon_abs)*111302.62) + ((Point.lat-lat_abs)*110574.61)) <= radius)), and_(Point.lon>=0, Point.lat<0, ((((Point.lon-lon_abs)*111302.62) + (((Point.lat*-1)-lat_abs)*110574.61)) <= radius)), and_(Point.lon>=0, Point.lat>=0, ((((Point.lon-lon_abs)*111302.62) + ((Point.lat-lat_abs)*110574.61)) <= radius)))).all()
     a = contr.session.query(Event).filter(and_(Point.lon<0, Point.lat<0, ((((Point.lon*-1)-lon_abs)*111302.62) + (((Point.lat*-1)-lat_abs)*110574.61)) <= radius)).all()
     b = contr.session.query(Event).filter(and_(Point.lon<0, Point.lat>=0, ((((Point.lon*-1)-lon_abs)*111302.62) + ((Point.lat-lat_abs)*110574.61)) <= radius)).all()
-    c = contr.session.query(Event).filter(Event.point.has(and_(Point.lon>=0,
-                                               Point.lat<0,
-                                               (((Point.lon-lon_abs)*111302.62) + (((Point.lat*-1)-lat_abs)*110574.61)) <= radius,
-                                               1==1
-                                               )
-                                          )).all()
     d = contr.session.query(Event).filter(and_(Point.lon>=0, Point.lat>=0, (((Point.lon-lon_abs)*111302.62) + ((Point.lat-lat_abs)*110574.61)) <= radius)).all()
 
     # y = contr.query_CoT(query= [(((Point.lat-lat) * (Point.lon-lon)) + ((Point.lat-lat) * (Point.lat-lat)))<=radius**2])
