@@ -29,6 +29,7 @@ class SendDataController:
                         # by the server due to the list contents
                         # being within a list
                     except Exception as e:
+                        print(e)
                         logger.error('error in sending connection data ' + str(processedCoT.idData))
                         pass
                 copiedProcessedCoTObject = copy.deepcopy(processedCoT)
@@ -43,7 +44,7 @@ class SendDataController:
                 return self.returnData
         except Exception as e:
             logger.error(loggingConstants.SENDDATACONTROLLERSENDDATAINQUEUEERROR+str(e))
-            return Exception(e)
+            raise Exception(e)
 
     def send_to_specific_client(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
@@ -78,12 +79,12 @@ class SendDataController:
                     pass
                 return 1
         except Exception as e:
+            print(e)
             logger.error('error in send data to specific client ' + str(e))
             return -1
     def send_to_all(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
             for client in clientInformationQueue:
-
                 sock = client.socket
                 try:
                     if hasattr(processedCoT, 'xmlString'):
@@ -98,17 +99,22 @@ class SendDataController:
                         except TypeError:
                             sock.send(processedCoT.idData.encode())
                 except Exception as e:
-                    logger.error('error in sending of data ' + str(e))
+                    if str(e) != "timed out":
+                        logger.error('error in sending of data ' + str(e))
+                        continue
                     return (-1, client)
             if shareDataPipe != None:
                 processedCoT.clientInformation = None
-                shareDataPipe.put(processedCoT)
+                if processedCoT.clientInformation == None:
+                    shareDataPipe.put(processedCoT)
             else:
                 pass
             return 1
         except Exception as e:
             import traceback
-
+            print('exception SendDataController ln:110')
+            print(str(traceback.format_exc()))
+            print(clientInformationQueue)
             logger.error('error in send to all ' + str(e)+str(traceback.format_exc()))
             raise Exception(e)
     def geochat_sending(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
@@ -140,4 +146,5 @@ class SendDataController:
                     pass
                 return 1
         except Exception as e:
+            print(e)
             logger.error('there has been an exception in sending geochat ' + str(e))
\ No newline at end of file
