@@ -1,6 +1,6 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables._GroupVariables import _GroupVariables as vars
-
-class _Group:
+class _Group(FTSProtocolObject):
     def __init__(self):
         self.name = None
         self.role = None
@@ -19,6 +19,13 @@ class _Group:
         _group.setrole(ROLE)
         return _group
 
+    @staticmethod
+    def Presence(NAME=vars.Presence().name, ROLE=vars.Presence().role):
+        _group = _Group()
+        _group.setname(NAME)
+        _group.setrole(ROLE)
+        return _group
+
     def getrole(self):
         return self.role
 
