@@ -15,4 +15,11 @@ class TrackVariables:
         cls.speed = None
         cls.course = None
         cls.SLOPE = None
+        return cls
+
+    @classmethod
+    def DroneSensor(cls):
+        cls.SPEED = "-0.00"
+        cls.COURSE = "46"
+        cls.SLOPE = "0.00"
         return cls
\ No newline at end of file
